@@ -1,11 +1,16 @@
 package Sah::Schema::even;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.071'; # VERSION
+our $DATE = '2020-03-02'; # DATE
+our $VERSION = '0.072'; # VERSION
 
 our $schema = ['int', {
     summary => 'Even number',
     div_by => 2,
+    examples => [
+        {data=>0, valid=>1},
+        {data=>2, valid=>1},
+        {data=>1, valid=>0},
+    ],
 }, {}];
 
 1;
@@ -23,7 +28,7 @@ Sah::Schema::even - Even number
 
 =head1 VERSION
 
-This document describes version 0.071 of Sah::Schema::even (from Perl distribution Sah-Schemas-Int), released on 2018-04-03.
+This document describes version 0.072 of Sah::Schema::even (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
 
 =head1 HOMEPAGE
 
@@ -31,7 +36,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Sah-Schema-Int>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Int>.
 
 =head1 BUGS
 
@@ -47,7 +52,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
