@@ -1,12 +1,19 @@
 package Sah::Schema::int128;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.071'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Int'; # DIST
+our $VERSION = '0.072'; # VERSION
 
 our $schema = [int => {
     summary => '32-bit signed integer',
     min     => -2**127,
     max     => +2**127-1,
+    examples => [
+        {data=>0  , valid=>1},
+        {data=>1.1, valid=>0},
+        # XXX test out-of-range ints
+    ],
 }, {}];
 
 1;
@@ -24,7 +31,7 @@ Sah::Schema::int128 - 32-bit signed integer
 
 =head1 VERSION
 
-This document describes version 0.071 of Sah::Schema::int128 (from Perl distribution Sah-Schemas-Int), released on 2018-04-03.
+This document describes version 0.072 of Sah::Schema::int128 (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
 
 =head1 HOMEPAGE
 
@@ -32,7 +39,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Sah-Schema-Int>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Int>.
 
 =head1 BUGS
 
@@ -48,7 +55,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
