@@ -1,12 +1,20 @@
 package Sah::Schema::int8;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.071'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Int'; # DIST
+our $VERSION = '0.072'; # VERSION
 
 our $schema = [int => {
     summary => '8-bit signed integer',
     min     => -2**7,
     max     => +2**7-1,
+    examples => [
+        {data=>0, valid=>1},
+        {data=>127, valid=>1},
+        {data=>128, valid=>0},
+        {data=>255, valid=>0},
+    ],
 }, {}];
 
 1;
@@ -24,7 +32,7 @@ Sah::Schema::int8 - 8-bit signed integer
 
 =head1 VERSION
 
-This document describes version 0.071 of Sah::Schema::int8 (from Perl distribution Sah-Schemas-Int), released on 2018-04-03.
+This document describes version 0.072 of Sah::Schema::int8 (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
 
 =head1 HOMEPAGE
 
@@ -32,7 +40,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Sah-Schema-Int>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Int>.
 
 =head1 BUGS
 
@@ -48,7 +56,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
