@@ -1,7 +1,9 @@
 package Sah::Schema::posint;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.071'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Int'; # DIST
+our $VERSION = '0.072'; # VERSION
 
 our $schema = [int => {
     summary   => 'Positive integer (1, 2, ...)',
@@ -9,9 +11,14 @@ our $schema = [int => {
     description => <<'_',
 
 Zero is not included in this schema because zero is neither positive nor
-negative. See also `nonnegint` for integers that start from 0.
+negative. See also `uint` for integers that start from 0.
 
 _
+    examples => [
+        {data=> 1, valid=>1},
+        {data=> 0, valid=>0},
+        {data=>-1, valid=>0},
+    ],
 }, {}];
 
 1;
@@ -29,12 +36,12 @@ Sah::Schema::posint - Positive integer (1, 2, ...)
 
 =head1 VERSION
 
-This document describes version 0.071 of Sah::Schema::posint (from Perl distribution Sah-Schemas-Int), released on 2018-04-03.
+This document describes version 0.072 of Sah::Schema::posint (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
 Zero is not included in this schema because zero is neither positive nor
-negative. See also C<nonnegint> for integers that start from 0.
+negative. See also C<uint> for integers that start from 0.
 
 =head1 HOMEPAGE
 
@@ -42,7 +49,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Sah-Schema-Int>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Int>.
 
 =head1 BUGS
 
@@ -58,7 +65,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
