@@ -1,7 +1,9 @@
 package Sah::Schema::uint;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.071'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Int'; # DIST
+our $VERSION = '0.072'; # VERSION
 
 our $schema = [int => {
     summary   => 'Non-negative integer (0, 1, 2, ...)',
@@ -11,6 +13,11 @@ our $schema = [int => {
 See also `posint` for integers that start from 1.
 
 _
+    examples => [
+        {data=> 0, valid=>1},
+        {data=> 1, valid=>1},
+        {data=>-1, valid=>0},
+    ],
  }, {}];
 
 1;
@@ -28,7 +35,7 @@ Sah::Schema::uint - Non-negative integer (0, 1, 2, ...)
 
 =head1 VERSION
 
-This document describes version 0.071 of Sah::Schema::uint (from Perl distribution Sah-Schemas-Int), released on 2018-04-03.
+This document describes version 0.072 of Sah::Schema::uint (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
@@ -40,7 +47,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Sah-Schema-Int>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Int>.
 
 =head1 BUGS
 
@@ -56,7 +63,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
